Poison

Trait Poison 

pub trait Poison: Copy {
    // Required method
    fn is_poisoned(self, ast: &Ast) -> bool;
}
A node that recovery may have poisoned.

Implemented for the three node kinds that have an error variant, so that a diagnostic can be held back by the node it is about whatever kind of node that is.

Required Methods

fn is_poisoned(self, ast: &Ast) -> bool

Whether this is a node recovery put in the tree rather than one the source asked for.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Poison for DeclId

Source

fn is_poisoned(self, ast: &Ast) -> bool

Source

impl Poison for ExprId

Source

fn is_poisoned(self, ast: &Ast) -> bool

Source

impl Poison for StmtId

Source

fn is_poisoned(self, ast: &Ast) -> bool

Implementors