pub trait Poison: Copy {
// Required method
fn is_poisoned(self, ast: &Ast) -> bool;
}Expand description
A node that recovery may have poisoned.
Implemented for the three node kinds that have an error variant, so that a diagnostic can be held back by the node it is about whatever kind of node that is.
Required Methods
Sourcefn is_poisoned(self, ast: &Ast) -> bool
fn is_poisoned(self, ast: &Ast) -> bool
Whether this is a node recovery put in the tree rather than one the source asked for.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".